/***
 * GASP: a gaming services platform for mobile multiplayer games.
 * MooDS: a communication protocol used in GASP.
 * GASP Demonstrator: a gasp demonstration game.
 *
 * Copyright (C) 2004 CNAM/INT
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contact: gasp-team@objectweb.org
 *
 * Author: Franck Caron, Romain Pellerin
 */
/*
 * Created on 2 december 2005
 *
 * @author CARON Franck - CNAM CEDRIC
 * @author PELLERIN Romain - CNAM CEDRIC
 * @author DELPIANO Fabien - Filao
 * 
 * 
 * Research project: CNAM-CEDRIC - INT - Filao
 */

package app2.client.game;
import javax.microedition.lcdui.Graphics;

public abstract class Actor {

	protected GameCanvas game;
	protected String username;

	public Actor(GameCanvas game) {
		this.game = game;
		initialize();
	}

	public abstract void initialize();
	
	/*** Action management ***/
	protected int x, y;
	private int speed_x, speed_y;

	public int getX() {
		return x;
	}

	public int getY() {
		return y;
	}
	
	public int getSpeedX() {
		return speed_x;
	}

	public int getSpeedY() {
		return speed_y;
	}

	public void moveX(int dx, long delta_time) {
		x += dx * delta_time;
		if (x < 0) x = 0;
		else if (x > game.xMax) x = game.xMax;
	}

	public void moveY(int dy, long delta_time) {
		y += dy * delta_time;
		if (y < 0) y = 0;
		else if (y > game.yMax) y = game.yMax;
	}

	public void setSpeed(int speed_x, int speed_y) {
		this.speed_x = speed_x;
		this.speed_y = speed_y;
	}
	/*** In game management ***/
	private boolean in_game = false;

	public void addedNotify() {
		in_game = true;
	}

	public void removedNotify() {
		in_game = false;
	}

	public boolean isInGame() {
		return in_game;
	}

	/*** Actions ***/
	public void executeActions(long time, long delta_time) {
		moveX(speed_x, delta_time);
		moveY(speed_y, delta_time);
	}

	/****** Graphic ******/
	public void paint(Graphics g, long gameTime, long deltaTime) {
    }

}
